from distutils.core import setup

setup(
    name = 'py-timed-dialog',
    packages = ['ptd'],
    version = '0.0.1',
    description = 'A Python module to create dialog boxes that self destruct after a set period of time',
    author = 'Rohith PR',
    author_email = 'praroh2@gmail.com',
    url = 'https://github.com/rohithpr/py-timed-dialog',
    download_url = 'https://github.com/rohithpr/py-timed-dialog/tarball/0.0.1',
    keywords = ['gui', 'dialog box', 'timeout dialog box'],
    classifiers = [
        'Intended Audience :: Developers',
        'Intended Audience :: End Users/Desktop',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development :: Libraries :: Tcl Extensions',
    ],
)
